@@ -218,24 +218,9 @@ def test_uart_frame_received_error(connected_uart, mocker):
     uart.data_received(test_frame_bytes * 3)
 
     # We should have received all three frames
-    znp.frame_received.call_count == 3
+    assert znp.frame_received.call_count == 3
 
 
-@pytest.mark.timeout(1)
-@pytest.mark.asyncio
-async def test_connect_auto(dummy_serial_conn, mocker):
-    device, _ = dummy_serial_conn
-
-    mocker.patch("zigpy_znp.uart.guess_port", return_value=device)
-
-    znp = mocker.Mock()
-    await znp_uart.connect(
-        conf.SCHEMA_DEVICE({conf.CONF_DEVICE_PATH: "auto"}), api=znp, toggle_rts=False
-    )
-
-
-@pytest.mark.timeout(1)
-@pytest.mark.asyncio
 async def test_connection_lost(dummy_serial_conn, mocker, event_loop):
     device, _ = dummy_serial_conn
 
@@ -244,80 +229,20 @@ async def test_connection_lost(dummy_serial_conn, mocker, event_loop):
     znp.connection_lost = conn_lost_fut.set_result
 
     protocol = await znp_uart.connect(
-        conf.SCHEMA_DEVICE({conf.CONF_DEVICE_PATH: device}), api=znp, toggle_rts=False
+        conf.SCHEMA_DEVICE({conf.CONF_DEVICE_PATH: device}), api=znp
     )
 
     exception = RuntimeError("Uh oh, something broke")
     protocol.connection_lost(exception)
 
-    # Losing a connection propagates up to the znp
+    # Losing a connection propagates up to the ZNP object
     assert (await conn_lost_fut) == exception
 
-    znp.reset_mock()
-    conn_closed_fut = event_loop.create_future()
-    znp.connection_lost = conn_closed_fut.set_result
 
-    protocol = await znp_uart.connect(
-        conf.SCHEMA_DEVICE({conf.CONF_DEVICE_PATH: device}), api=znp, toggle_rts=False
-    )
-    protocol.close()
-
-    # Closing a connection does as well
-    assert (await conn_closed_fut) is None
-
-
-@pytest.mark.timeout(1)
-@pytest.mark.asyncio
 async def test_connection_made(dummy_serial_conn, mocker):
     device, _ = dummy_serial_conn
     znp = mocker.Mock()
 
-    await znp_uart.connect(
-        conf.SCHEMA_DEVICE({conf.CONF_DEVICE_PATH: device}), api=znp, toggle_rts=False
-    )
+    await znp_uart.connect(conf.SCHEMA_DEVICE({conf.CONF_DEVICE_PATH: device}), api=znp)
 
     znp.connection_made.assert_called_once_with()
-
-
-@pytest.mark.timeout(1)
-@pytest.mark.asyncio
-async def test_no_toggle_rts(dummy_serial_conn, mocker):
-    device, serial = dummy_serial_conn
-
-    type(serial).dtr = dtr = mocker.PropertyMock()
-    type(serial).rts = rts = mocker.PropertyMock()
-
-    znp = mocker.Mock()
-
-    await znp_uart.connect(
-        conf.SCHEMA_DEVICE({conf.CONF_DEVICE_PATH: device}), api=znp, toggle_rts=False
-    )
-
-    assert dtr.mock_calls == []
-    assert rts.mock_calls == []
-
-
-@pytest.mark.timeout(1)
-@pytest.mark.asyncio
-async def test_toggle_rts(dummy_serial_conn, mocker):
-    device, serial = dummy_serial_conn
-
-    type(serial).dtr = dtr = mocker.PropertyMock()
-    type(serial).rts = rts = mocker.PropertyMock()
-
-    znp = mocker.Mock()
-
-    await znp_uart.connect(
-        conf.SCHEMA_DEVICE({conf.CONF_DEVICE_PATH: device}), api=znp, toggle_rts=True
-    )
-
-    assert dtr.mock_calls == [
-        mocker.call(False),
-        mocker.call(False),
-        mocker.call(False),
-    ]
-    assert rts.mock_calls == [
-        mocker.call(False),
-        mocker.call(True),
-        mocker.call(False),
-    ]
